# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.0.0~1d16f01',
    built_at='2023-11-13 15:15:25Z',
    sha='1d16f0176b98178946bb47d9f95e0f09c97b371a',
    branch='HEAD',
    tag='v4.0.0',
)
